/*
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 * 
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.fieldplan.model;

import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import java.beans.PropertyVetoException;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import nl.cloudfarming.client.field.model.PartField;

/**
 * A FieldPlan is the collection of operational data grouped for a harvest year.
 * All data related to fields and or crops in a certain period or time will be placed
 * in a field plan. Examples of such elements are:
 * - Production Units
 * - Sensor data
 * - unoccupied fields
 * 
 * 
 * @author Timon Veenstra <monezz@gmail.com>
 */
public class FieldPlan implements Serializable{

    private Integer harvestYear;
    public static final String PROP_HARVESTYEAR = "harvestYear";
    private List<PartField> partFields = new ArrayList<>();
    
    /**
     * Get the value of harvestYear
     *
     * @return the value of harvestYear
     */
    public Integer getHarvestYear() {
        return harvestYear;
    }

    public List<PartField> getPartFields() {
        return partFields;
    }
    
    public void addPartField(PartField partField){
        this.partFields.add(partField);        
    }
    
    
    /**
     * Set the value of harvestYear
     *
     * @param harvestYear new value of harvestYear
     */
    public void setHarvestYear(Integer harvestYear) {
        Integer oldHarvestYear = this.harvestYear;
        this.harvestYear = harvestYear;
        getPropertyChangeSupport().firePropertyChange(PROP_HARVESTYEAR, oldHarvestYear, harvestYear);
    }
    private transient PropertyChangeSupport propertyChangeSupport;
    
    public PropertyChangeSupport getPropertyChangeSupport() {
        if(propertyChangeSupport == null){
            propertyChangeSupport= new PropertyChangeSupport(this);
        }
        return propertyChangeSupport;
    }
    
        

    /**
     * Add PropertyChangeListener.
     *
     * @param listener
     */
    public void addPropertyChangeListener(PropertyChangeListener listener) {
        getPropertyChangeSupport().addPropertyChangeListener(listener);
    }

    /**
     * Remove PropertyChangeListener.
     *
     * @param listener
     */
    public void removePropertyChangeListener(PropertyChangeListener listener) {
        getPropertyChangeSupport().removePropertyChangeListener(listener);
    }
    private String name;
    public static final String PROP_NAME = "name";

    /**
     * Get the value of name
     *
     * @return the value of name
     */
    public String getName() {
        return name;
    }

    /**
     * Set the value of name
     *
     * @param name new value of name
     * @throws java.beans.PropertyVetoException
     */
    public void setName(String name) {
        String oldName = this.name;
        this.name = name;
        getPropertyChangeSupport().firePropertyChange(PROP_NAME, oldName, name);
    }


}
