/*
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 * 
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.fieldplan.model;

import java.util.List;
import nl.cloudfarming.client.field.model.PartField;
import org.openide.filesystems.FileObject;

/**
 * Service for handling Field plans
 * Register your implementation as follows
 * Implement this interface and add @Serviceprovider(service=FieldPlanService.class) above your class definition
 * @author Merijn Zengers
 */
public interface FieldPlanService {    
    
    /**
     * Adds a new fieldPlan to the provided fieldPlanFolder
     * @param harvestYear the harvest year of the new field plan
     * @param fieldPlanFolder the folder in which to create the new fieldplan
     * @return the created FieldPlan
     */
    FieldPlan addFieldPlan(String name, Integer harvestYear, FileObject farmFolder);
    
    /**
     * Adds a new FieldPlan and ads the provided partFields to it while creating it
     * @param name
     * @param harvestYear
     * @param fieldPlanFolder
     * @param partFields
     * @return 
     */
    FieldPlan addFieldPlan(String name, Integer harvestYear, FileObject farmFolder, List<PartField> partFields);
    
}
